==> monitoring-8.x-1.12.tar.gz: monitoring/tests/src/Functional/MonitoringCaptchaTest.php <==
<?php

namespace Drupal\Tests\monitoring\Functional;

/**
 * Tests the captcha failed attempts sensor.
 *
 * @group monitoring
 * @dependencies captcha
 */
class MonitoringCaptchaTest extends MonitoringTestBase {

  /**
   * Modules to install.
   *
   * @var array
   */
  protected static $modules = array('captcha', 'node');

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    // Add captcha.inc file.
    module_load_include('inc', 'captcha');
  }

  /**
   * Tests the captcha failed attempts sensor.
   */
  public function testCaptchaSensor() {

    // Create user and test log in without CAPTCHA.
    $user = $this->drupalCreateUser();
    $this->drupalLogin($user);
    // Log out again.
    $this->drupalLogout();

    // Set a CAPTCHA on login form.
    captcha_set_form_id_setting('user_login_form', 'captcha/Math');

    // Assert the number of entries in the captcha_session table is 1.
    $this->assertEquals(\Drupal::database()->query('SELECT COUNT (*) FROM {captcha_sessions}')->fetchField(), 0);
    // Try to log in, with invalid captcha answer which should fail.
    $edit = array(
      'name' => $user->getAccountName(),
      'pass' => $user->pass_raw,
      'captcha_response' => '?',
    );
    $this->drupalGet('user');
    $this->submitForm($edit, t('Log in'));

    // Assert the total number of entries in captcha_sessions table is now 2.
    $this->assertEquals(\Drupal::database()->query('SELECT COUNT (*) FROM {captcha_sessions}')->fetchField(), 1);

    // Run sensor and get the message.
    $message = $this->runSensor('captcha_failed_count')->getMessage();

    // Assert the number of failed attempts.
    $this->assertEquals($message, '1 attempt(s)');
  }

}

==> monitoring-8.x-1.14.tar.gz: monitoring/tests/src/Functional/MonitoringCaptchaTest.php <==
<?php

namespace Drupal\Tests\monitoring\Functional;

/**
 * Tests the captcha failed attempts sensor.
 *
 * @group monitoring
 * @dependencies captcha
 */
class MonitoringCaptchaTest extends MonitoringTestBase {

  /**
   * Modules to install.
   *
   * @var array
   */
  protected static $modules = array('captcha', 'node');

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    // Add captcha.inc file.
    \Drupal::moduleHandler()->loadInclude('captcha', 'inc');
  }

  /**
   * Tests the captcha failed attempts sensor.
   */
  public function testCaptchaSensor() {

    // Create user and test log in without CAPTCHA.
    $user = $this->drupalCreateUser();
    $this->drupalLogin($user);
    // Log out again.
    $this->drupalLogout();

    // Set a CAPTCHA on login form.
    captcha_set_form_id_setting('user_login_form', 'captcha/Math');

    // Assert the number of entries in the captcha_session table is 1.
    $this->assertEquals(\Drupal::database()->query('SELECT COUNT (*) FROM {captcha_sessions}')->fetchField(), 0);
    // Try to log in, with invalid captcha answer which should fail.
    $edit = array(
      'name' => $user->getAccountName(),
      'pass' => $user->pass_raw,
      'captcha_response' => '?',
    );
    $this->drupalGet('user');
    $this->submitForm($edit, 'Log in');

    // Assert the total number of entries in captcha_sessions table is now 2.
    $this->assertEquals(\Drupal::database()->query('SELECT COUNT (*) FROM {captcha_sessions}')->fetchField(), 1);

    // Run sensor and get the message.
    $message = $this->runSensor('captcha_failed_count')->getMessage();

    // Assert the number of failed attempts.
    $this->assertEquals($message, '1 attempt(s)');
  }

}
